@@ -123,6 +123,7 @@ class Focusr(object):
                         target=vtk_mesh_target, source=vtk_mesh_source, transform_mode="similarity"
                     )
                 vtk_mesh_source = apply_transform(source=vtk_mesh_source, transform=icp)
+            self._icp_transform = icp
         print("Starting to build first graph")
         # Build target graph
         self.graph_target = Graph(
@@ -646,7 +647,6 @@ class Focusr(object):
         include_unaligned=False,
         upscale_factor=10.0,
     ):
-
         point_sets = []
 
         if include_target_coordinates is True:
@@ -778,3 +778,15 @@ class Focusr(object):
 
         plotter = Viewer(geometries=geometries, shadow=shadow)
         return plotter
+
+    @property
+    def icp_transform(self):
+        """
+        Convenience property to return the ICP transform.
+
+        Returns
+        -------
+        vtk.vtkTransform
+            The fitted ICP transform.
+        """
+        return self._icp_transform
